@@ -41,6 +41,18 @@ type TimerThread = timeout_list::TimerThread<TimerData>;
 fn filter_cancel_panic() {
     use generator::Error;
     use std::panic;
+    if thread::panicking(){
+        for _ in 0..100{
+            crate::coroutine::yield_now();
+            if !thread::panicking(){
+                break
+            }
+        }
+    }
+    if thread::panicking(){
+        // cancel take_hook
+        return;
+    }
     let old = panic::take_hook();
     ::std::panic::set_hook(Box::new(move |info| {
         if let Some(&Error::Cancel) = info.payload().downcast_ref::<Error>() {
