@@ -1,5 +1,8 @@
 pub mod queue;
+#[macro_use]
 pub mod sync;
 pub mod http;
 pub mod errors;
-pub mod io;
\ No newline at end of file
+pub mod io;
+#[macro_use]
+pub mod defer;
\ No newline at end of file
