@@ -16,19 +16,17 @@ use crossbeam::queue::SegQueue;
 
 /// Create an unbounded channel. if If you want to limit the number of messages, use bounded channel_buf()
 pub fn channel<T>() -> (Sender<T>, Receiver<T>) {
-    let a = Arc::new(InnerQueue::new());
-    (Sender::new(a.clone()), Receiver::new(a))
+    bounded(usize::MAX)
 }
 
 /// Create a bounded mpmc channel(More producers, more consumers)
 pub fn channel_buf<T>(buf: usize) -> (Sender<T>, Receiver<T>) {
-    let a = Arc::new(InnerQueue::new_buffer(buf));
-    (Sender::new(a.clone()), Receiver::new(a))
+    bounded(buf)
 }
 
 /// Create an unbounded channel. if If you want to limit the number of messages, use bounded channel_buf()
 pub fn unbounded<T>() -> (Sender<T>, Receiver<T>) {
-    channel_buf(usize::MAX)
+    bounded(usize::MAX)
 }
 
 /// Create a bounded channel
@@ -37,6 +35,22 @@ pub fn bounded<T>(buf: usize) -> (Sender<T>, Receiver<T>) {
     (Sender::new(a.clone()), Receiver::new(a))
 }
 
+/// create an channel(mpmc)
+///  for example:
+///   //bounded
+///   let (sender, receiver) = chan!(2);
+///   //unbounded
+///   let (sender, receiver) = chan!();
+#[macro_export]
+macro_rules! chan {
+    () => {
+        $crate::std::sync::mpsc::bounded(usize::MAX)
+    };
+    ($num:expr) => {
+        $crate::std::sync::mpsc::bounded($num)
+    };
+}
+
 
 /// /////////////////////////////////////////////////////////////////////////////
 /// InnerQueue
